@@ -33,9 +33,10 @@
 #  define KDEPIMDBUSINTERFACES_DEPRECATED_NO_EXPORT KDEPIMDBUSINTERFACES_NO_EXPORT KDEPIMDBUSINTERFACES_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KDEPIMDBUSINTERFACES_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KDEPIMDBUSINTERFACES_NO_DEPRECATED
+#    define KDEPIMDBUSINTERFACES_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
